#
# spec file for package perl-SVN-Dump
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-SVN-Dump
Version:        0.06
Release:        1.1
%define cpan_name SVN-Dump
Summary:        A Perl interface to Subversion dumps
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/SVN-Dump/
Source:         http://www.cpan.org/authors/id/B/BO/BOOK/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build) >= 0.38
%{perl_requires}

%description
An SVN::Dump object represents a Subversion dump.

This module follow the semantics used in the reference document (the file
_notes/fs_dumprestore.txt_ in the Subversion source tree):

* *

  A dump is a collection of records (the SVN::Dump::Record manpage
  objects).

* *

  A record is composed of a set of headers (a the SVN::Dump::Headers
  manpage object), a set of properties (a the SVN::Dump::Property manpage
  object) and an optional bloc of text (a the SVN::Dump::Text manpage
  object).

* *

  Some special records ('delete' records with a 'Node-kind' header)
  recursively contain included records.

Each class has a 'as_string()' method that prints its content in the dump
format.

The most basic thing you can do with SVN::Dump is simply copy a dump:

    use SVN::Dump;

    my $dump = SVN::Dump->new( 'mydump.svn' );
    print $dump->as_string(); # only print the dump header

    while( $rec = $dump->next_record() ) {
        print $rec->as_string();
    }

After the operation, the resulting dump should be identical to the original
dump.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes eg README

%changelog
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.06
  see /usr/share/doc/packages/perl-SVN-Dump/Changes
  0.06 Fri May 31 2013
    [ENHANCEMENTS]
  - speed optimization when reading a dump (thanks to Andrew Sayers)
    [DOCUMENTATION]
  - a few documentation tweaks (thanks to David Landgren)
  - imoproved inter-documentation links
* Sat Feb 19 2011 pascal.bleser@opensuse.org
- update to 0.05:
  * add support for Text-content-sha1 node property
  * don't create text or property blocks if they don't exist in a dump
  * add a digest() method to SVN::Dump::Text (RT#56868)
  * add support for Text-content-sha1 / Text-copy-source-sha1 (RT#60207)
  * new option check_digest that will, when reading a non-delta dump, ensure
    that the content digest are valid
  * properly ignore blank lines between records (RT#25467, RT#28645)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sat Jun 19 2010 pascal.bleser@opensuse.org
- initial package (0.04)
